==> phoenix-5.2.0-src.tar.gz: phoenix-5.2.0/phoenix-core-client/src/main/java/org/apache/phoenix/util/TrustedByteArrayOutputStream.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.phoenix.util;

import java.io.ByteArrayOutputStream;
import java.io.IOException;

/**
 * 
 * Derived version of {@link java.io.ByteArrayOutputStream} that provides access
 * to underlying byte array buffer so that it doesn't have to be copied
 *
 * 
 * @since 0.1
 */
public class TrustedByteArrayOutputStream extends ByteArrayOutputStream {
    public TrustedByteArrayOutputStream(int initialSize) {
        super(initialSize);
    }
    public byte[] getBuffer() {
        return buf;
    }
    @Override
    public byte[] toByteArray() {
        if (buf.length == size()) {
            return buf;
        }
        return super.toByteArray();
    }
    @Override
    public void write(byte[] b) {
        try {
            super.write(b);
        } catch (IOException e) {
            throw new RuntimeException(e); // Impossible
        }
    }
}

==> phoenix-5.3.0-src.tar.gz: phoenix-5.3.0/phoenix-core-client/src/main/java/org/apache/phoenix/util/TrustedByteArrayOutputStream.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.phoenix.util;

import java.io.ByteArrayOutputStream;
import java.io.IOException;

/**
 * Derived version of {@link java.io.ByteArrayOutputStream} that provides access to underlying byte
 * array buffer so that it doesn't have to be copied
 * @since 0.1
 */
public class TrustedByteArrayOutputStream extends ByteArrayOutputStream {
  public TrustedByteArrayOutputStream(int initialSize) {
    super(initialSize);
  }

  public byte[] getBuffer() {
    return buf;
  }

  @Override
  public byte[] toByteArray() {
    if (buf.length == size()) {
      return buf;
    }
    return super.toByteArray();
  }

  @Override
  public void write(byte[] b) {
    try {
      super.write(b);
    } catch (IOException e) {
      throw new RuntimeException(e); // Impossible
    }
  }
}
